@@ -45,7 +45,7 @@ class HighlightableItem;
 #include "libkcardgame_export.h"
 class KCardPile;
 
-#include <QtCore/QSet>
+#include <QSet>
 #include <QGraphicsScene>
 
 class LIBKCARDGAME_EXPORT KCardScene : public QGraphicsScene
@@ -66,7 +66,7 @@ public:
     };
     Q_DECLARE_FLAGS(SceneAlignment, SceneAlignmentFlag)
 
-    KCardScene( QObject * parent = 0 );
+    explicit KCardScene( QObject * parent = 0 );
     ~KCardScene();
 
     void setDeck( KAbstractCardDeck * deck );
